struct PageInbox<'a> {
page_data: PageData<'a>,
message: String,
sender_id: u32,
sender_name: String,
}Expand description
Page data: inbox.html
Fields
page_data: PageData<'a>message: Stringsender_id: u32sender_name: StringTrait Implementations
Sourceimpl<'a> Display for PageInbox<'a>
impl<'a> Display for PageInbox<'a>
Please be aware of the rendering performance notice in the [Template][askama::Template] trait.
Sourceimpl<'a> FastWritable for PageInbox<'a>
impl<'a> FastWritable for PageInbox<'a>
Sourcefn write_into(&self, dest: &mut dyn Write, values: &dyn Values) -> Result<()>
fn write_into(&self, dest: &mut dyn Write, values: &dyn Values) -> Result<()>
Used internally by askama to speed up writing some types.
Sourceimpl<'a> Template for PageInbox<'a>
impl<'a> Template for PageInbox<'a>
Sourceconst SIZE_HINT: usize = 8376usize
const SIZE_HINT: usize = 8376usize
Provides a rough estimate of the expanded length of the rendered template. Larger
values result in higher memory usage but fewer reallocations. Smaller values result in the
opposite. This value only affects
render. It does not take effect when calling
render_into, write_into, the fmt::Display implementation, or the blanket
ToString::to_string implementation.Sourcefn render_into_with_values(
&self,
__askama_writer: &mut dyn Write,
__askama_values: &dyn Values,
) -> Result<()>
fn render_into_with_values( &self, __askama_writer: &mut dyn Write, __askama_values: &dyn Values, ) -> Result<()>
fn render(&self) -> Result<String, Error>
fn render(&self) -> Result<String, Error>
Helper method which allocates a new
String and renders into it. Read morefn render_with_values(&self, values: &dyn Values) -> Result<String, Error>
fn render_with_values(&self, values: &dyn Values) -> Result<String, Error>
fn render_into(&self, writer: &mut dyn Write) -> Result<(), Error>
fn render_into(&self, writer: &mut dyn Write) -> Result<(), Error>
Renders the template to the given
writer fmt buffer. Read moreAuto Trait Implementations
impl<'a> Freeze for PageInbox<'a>
impl<'a> RefUnwindSafe for PageInbox<'a>
impl<'a> Send for PageInbox<'a>
impl<'a> Sync for PageInbox<'a>
impl<'a> Unpin for PageInbox<'a>
impl<'a> UnsafeUnpin for PageInbox<'a>
impl<'a> UnwindSafe for PageInbox<'a>